@@ -1,7 +1,7 @@
 package GIS::Distance;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Class::Measure::Length qw( length );
 use Carp qw( croak );
@@ -14,8 +14,8 @@ sub new {
     $formula ||= 'Haversine';
 
     my $self = bless {
-        formula => $formula,
-        args    => \@args,
+        formula      => $formula,
+        formula_args => \@args,
     }, $class;
 
     my @modules;
@@ -36,11 +36,11 @@ sub new {
                 next;
             }
 
-            $code = $module->can('distance');
-            die "$module does not have a distance() function" if !$code;
+            $code = $module->can('_distance') || $module->can('distance');
+            die "$module does not have a _distance() or distance() sub" if !$code;
         }
 
-        $self->{module} = $module;
+        $self->{formula_module} = $module;
         $self->{code} = $code;
         last;
     }
@@ -52,8 +52,8 @@ sub new {
 };
 
 sub formula { $_[0]->{formula} }
-sub args { $_[0]->{args} }
-sub module { $_[0]->{module} }
+sub formula_args { $_[0]->{args} }
+sub formula_module { $_[0]->{module} }
 
 sub distance {
     my $self = shift;
@@ -72,7 +72,7 @@ sub distance {
         if @coords!=4;
 
     return length(
-        $self->{code}->( @coords, @{$self->{args}} ),
+        $self->{code}->( @coords, @{$self->{formula_args}} ),
         'km',
     );
 }
@@ -155,19 +155,29 @@ Does no argument checking.
 
 =item *
 
-Does not support formula L</args>, which are needed by at least the
-L<GIS::Distance::GeoEllipsoid> formula.
+Does not support L</formula_args>, which are supported by at least the
+L<GIS::Distance::GeoEllipsoid> formula.  Read more in the L</SPEED> section.
 
 =back
 
 Calling this gets you pretty close to the fastest bare metal speed you can get.
-The speed improvements of calling this is noticeable over millions of iterations
-only and you've got to decide if its worth the safety and features you are dropping.
+The speed improvements of calling this is noticeable over hundreds of thousands of
+iterations only and you've got to decide if its worth the safety and features
+you are dropping.
+
+=head1 ARGUMENTS
+
+    my $gis = GIS::Distance->new( $formula, @formula_args );
+
+When you call C<GIS::Distance->new()> you may pass a formula for L</formula>
+and any additional arguments will be slurped into L</formula_args>.
 
 =head1 ATTRIBUTES
 
 =head2 formula
 
+    print $gis->formula();
+
 Returns the formula name which was passed as the first argument to C<new()>.
 
 The formula can be specified as a partial or full module name for that
@@ -186,17 +196,20 @@ the C<Fast::> versions of the formulas, written in C, are not available and the
 pure perl ones will be used instead.  If you would like the C<Fast::> formulas
 then install L<GIS::Distance::Fast> and they will be automatically used.
 
-You may disable the automatic use of the C<Fast::> formulas by setting the
-C<GIS_DISTANCE_PP> environment variable.
+You may globally disable the automatic use of the C<Fast::> formulas by setting
+the C<GIS_DISTANCE_PP> environment variable.  Although, its likely simpler to
+just provide a full module name of a formula to get the same effect:
 
-=head2 args
+    my $gis = GIS::Distance->new( 'GIS::Distance::Haversine' );
+
+=head2 formula_args
 
 Returns the formula arguments, an array ref, containing the rest of the
 arguments passed to C<new()> (anything passed after the L</formula>).
 Most formulas do not take arguments.  If they do it will be described in
 their respective documentation.
 
-=head2 module
+=head2 formula_module
 
 Returns the fully qualified module name that L</formula> resolved to.
 
@@ -220,26 +233,33 @@ has.  For example you could bypass this module entirely and just do:
 The above would be the ultimate speed demon (as shown in benchmarking)
 but throws away some flexibility and adds some foot-gun support.
 
-Here's some benchmarks for these options:
+Here's a benchmarks for these options:
 
-    PP Haversine - GIS::Distance->distance                   125913/s
-    XS Haversine - GIS::Distance->distance                   203335/s
-    PP Haversine - GIS::Distance->distance_metal             366569/s
-    PP Haversine - GIS::Distance::Haversine::distance        390320/s
-    XS Haversine - GIS::Distance->distance_metal            3289474/s
-    XS Haversine - GIS::Distance::Fast::Haversine::distance 8064516/s
+    2019-03-13T09:34:00Z
+    GIS::Distance 0.15
+    GIS::Distance::Fast 0.12
+    GIS::Distance::Fast::Haversine 0.12
+    GIS::Distance::Haversine 0.15
+                                                                 Rate
+    PP Haversine - GIS::Distance->distance                   123213/s
+    XS Haversine - GIS::Distance->distance                   196232/s
+    PP Haversine - GIS::Distance->distance_metal             356379/s
+    PP Haversine - GIS::Distance::Haversine::distance        385208/s
+    XS Haversine - GIS::Distance->distance_metal            3205128/s
+    XS Haversine - GIS::Distance::Fast::Haversine::distance 8620690/s
 
 You can run your own benchmarks using the included C<author/bench>
 script.  The above results were produced with:
 
     author/bench -f Haversine
 
-Even the slowest result was C<125913/s>, which is C<125.913/ms>, which
-means each call took about C<0.0079ms>.
+The slowest result was about C<125000/s>, or about C<8ms> each call.
+This could be a substantial burden in some contexts, such as live HTTP
+responses to human users and running large batch jobs, to name just two.
 
 In conclusion, if you can justify the speed gain, switching to
-L</distance_metal> and installing L<GIS::Distance::Fast>, seems
-the ideal setup.
+L</distance_metal> and installing L<GIS::Distance::Fast> looks to be an
+ideal setup.
 
 As always, YMMV.
 
@@ -260,7 +280,7 @@ rad2deg function.
 
 =head1 FORMULAS
 
-These formulas come with this distribution:
+These formulas come bundled with this distribution:
 
 =over
 
@@ -304,27 +324,7 @@ These formulas are available on CPAN:
 
 =item *
 
-L<GIS::Distance::Fast::ALT>
-
-=item *
-
-L<GIS::Distance::Fast::Cosine>
-
-=item *
-
-L<GIS::Distance::Fast::GreatCircle>
-
-=item *
-
-L<GIS::Distance::Fast::Haversine>
-
-=item *
-
-L<GIS::Distance::Fast::Polar>
-
-=item *
-
-L<GIS::Distance::Fast::Vincenty>
+L<GIS::Distance::Fast/FORMULAS>
 
 =item *
 
@@ -342,8 +342,8 @@ L<Geo::Distance> - Is deprecated in favor of using this module.
 
 =item *
 
-L<Geo::Distance::Google> - While in the Geo::Distance, namespace this isn't
-actually related to Geo::Distance at all.  Might be useful.
+L<Geo::Distance::Google> - While in the Geo::Distance namespace, this isn't
+actually related to Geo::Distance at all.  Might be useful though.
 
 =item *
 
